summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorVishvananda Ishaya <vishvananda@gmail.com>2011-07-05 12:00:11 -0700
committerVishvananda Ishaya <vishvananda@gmail.com>2011-07-05 12:00:11 -0700
commit9a8254ef2751e1b7502107a9c6afe05ea1e2efd4 (patch)
treeb8050b03a647e4f8ebd8822665c5e49b64bbdc25
parent01b9d211e606ee0be221b27edae8aab1d35096ff (diff)
it is multi_host not multi_gateway
-rw-r--r--nova/network/api.py6
-rw-r--r--nova/network/manager.py5
2 files changed, 6 insertions, 5 deletions
diff --git a/nova/network/api.py b/nova/network/api.py
index c57394204..c0f0fb8eb 100644
--- a/nova/network/api.py
+++ b/nova/network/api.py
@@ -104,7 +104,8 @@ class API(base.Base):
'(%(project)s)') %
{'address': floating_ip['address'],
'project': context.project_id})
- if fixed_ip['network']['multi_gateway']:
+ # NOTE(vish): if we are multi_host, send to the instances host
+ if fixed_ip['network']['multi_host']:
host = fixed_ip['instance']['host']
else:
host = fixed_ip['network']['host']
@@ -122,7 +123,8 @@ class API(base.Base):
return
if not floating_ip.get('fixed_ip'):
raise exception.ApiError('Address is not associated.')
- if floating_ip['fixed_ip']['network']['multi_gateway']:
+ # NOTE(vish): if we are multi_host, send to the instances host
+ if floating_ip['fixed_ip']['network']['multi_host']:
host = floating_ip['fixed_ip']['instance']['host']
else:
host = floating_ip['fixed_ip']['network']['host']
diff --git a/nova/network/manager.py b/nova/network/manager.py
index f60763eba..84d2cbbcb 100644
--- a/nova/network/manager.py
+++ b/nova/network/manager.py
@@ -49,7 +49,6 @@ import datetime
import math
import netaddr
import socket
-import pickle
from eventlet import greenpool
from nova import context
@@ -129,8 +128,8 @@ class RPCAllocateFixedIP(object):
green_pool = greenpool.GreenPool()
for network in networks:
- # NOTE(vish): if we are multi_gateway pass to the specified host
- if not network['multi_gateway']:
+ # NOTE(vish): if we are not multi_host pass to the network host
+ if not network['multi_host']:
host = network['host']
if host != self.host:
# need to call allocate_fixed_ip to correct network host